==> serendipity_1.0.4.orig.tar.gz: serendipity/plugins/serendipity_event_spamblock/lang_pl.inc.php <==
<?php # $Id: lang_en.inc.php 1110 2006-04-18 10:04:30Z garvinhicking $

/**
 *  @version $Revision: 1110 $
 *  @author Kostas Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_EVENT_SPAMBLOCK_TITLE', 'Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_DESC', 'Rne metody na zwalczanie spamu w komentarzach');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY', 'Obrona przed spamem: Nieprawidowy komentarz.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_IP', 'Obrona przed spamem: Nie moesz wprowadzi kolejnego komentarza tak prdko. Prosz, poczekaj chwil (obrona przed floodem).');

@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_KILLSWITCH', 'Ten blog znajduje si w trybie "Cakowita blokada komentarzy". Prosz, wr tu za jaki czas, kiedy ten tryb zostanie zniesiony.');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE', 'Nie zezwalaj na zduplikowane komentarze');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE_DESC', 'Nie zezwalaj uytkownikom na dodanie komentarza, ktry ma tak sam zawarto jak dopiero co dodany komentarz (kolejne dodanie takiego samego komentarza)');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH', 'Cakowita blokada komentarzy');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH_DESC', 'Czasowe wyczenie moliwoci komentowania dla wszystkich wpisw. Przydatne kiedy Twj blog jest pod zmasowanym spamerskim atakiem.');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD', 'Czas blokowania adresu IP');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD_DESC', 'Zezwl na komentarze z danego adresu IP co n minut. Przydatne dla blokowania komentarzowych floodw (wiele komentarzy z tego samego adresu IP w krtkim czasie).');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS', 'Wcz Captcha');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_DESC', 'Wymusza na uytkowniku wpisanie specjalnego losowego kodu wywietlanego w wygenrowanym obrazku. Prosz, zwr uwag na to, e ludzie majcy problemy ze wzrokiem mog mie problemy z odczytaniem kodu.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC', 'Prosz, wpisz widoczny na obrazku kod do odpowiedniego pola. Twj komentarz zostanie dodany tylko gdy wpisany kod bdzie si zgadza z tym widocznym na obrazku. Prosz, upewnij si, e Twoja przegldarka ma wczon obsug cookies (ciasteczek) lub Twj komentarz nie przejdzie poprawnie weryfikacji.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2', 'Wpisz cig znakw, ktry tu widzisz do odpowiedniego pola!');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC3', 'Wpisz cig znakw widoczny na obrazku powyej: ');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_CAPTCHAS', 'Wprowadzie(a) nieprawidowy cig. Zerknij na obrazek i wprowad odpowiedni cig ponownie.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_NOTTF', 'Captcha nie bdzie dziaao na Twoim serwerze. Potrzebujesz zainstalowanych bibliotek GDLib i freetype oraz upewnij si, e odpowiednie pliki .ttf znajuj si w katalogu wtyczki.');

@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL', 'Wymu Captcha po ilu dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL_DESC', 'Moesz wymusi uzycie Captcha po okrelonej iloci dni. Wprowad iloc dni, po ktrych wprowadzenie Captcha bdzie wymagane. Jeli ustawione na 0 - bdzie wymagane zawsze.');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION', 'Wymu moderowanie komentarzy po ilu dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION_DESC', 'Moesz ustawi wymg moderowania wszystkich komentarzy. Wprowad ilo dni, po ktrych komentarze powinny podlega auto-moderacji. 0 wycza automoderacj.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE', 'Jak wiele linkw musi wystpi by komentarz podlega moderacji');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE_DESC', 'Jeli w komentarzu wystpi podana ilo linkw bdzie on wymaga moderacji. 0 oznacza wyczenie tej opcji.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT', 'Jak wiele linkw musi wystpi by komentarz zosta odrzucony');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT_DESC', 'Jeli w komentarzu wystpi podana ilo linkw, komentarz zostanie automatycznie odrzucony. 0 oznacza wyczenie tej opcji.');

@define('PLUGIN_EVENT_SPAMBLOCK_NOTICE_MODERATION', 'Z powodu warunkw okrelonych przez administratora bloga, Twj komentarz zosta oznaczony jako "wymagajcy sprawdzenia".');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR', 'Kolor ta captcha');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR_DESC', 'Wprowad wartoci RGB: 0,255,255');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE', 'Pooenie pliku z logiem');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE_DESC', 'Informacja o odrzuconych/wymagajcych moderowania komentarzach moe by przechowywania w pliku. Wyczy to pole jeli chcesz wyczy logowanie.');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_KILLSWITCH', 'Nagy wypadek: moliwo komentowania zostaa wyczona');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BODYCLONE', 'Zduplikowany komentarz');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_IPFLOOD', 'Zablokowane IP');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CAPTCHAS', 'Bdnie wprowadzone captcha (wprowadzono: %s, powinno by: %s)');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION', 'Auto-moderacja po X dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_REJECT', 'Zbyt wiele linkw');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_MODERATE', 'Zbyt wiele linkw');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL', 'Ukryj adresy e-mail komentujcych');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_DESC', 'Adresy e-mail komentujcych nie bd pokazywane');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_NOTICE', 'Adresy e-mail nie bd pokazywane i bd uywane tylko do celw wysyania powiadomie drog e-mailow');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE', 'Wybierz metod logowania');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DESC', 'Logi o odrzuconych komentarzach mog by przechowywane w Bazie danych lub w pliku tekstowym');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_FILE', 'Plik (patrz "Pooenie pliku z logiem")');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DB', 'Baza danych');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_NONE', 'Bez logowania');

@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS', 'Jak obsugiwa komentarze dokonywane via API');
@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS_DESC', 'To ustawienie odnosi si do komentarzy przesyanych przez API (lady (Trackbacks), WFW:commentAPI). Jeli wybrane jest ustawienie "moderuj", wszystkie te komentarze zawsze musz by wpierw zatwierdzone. Jeli wybrane jest ustawienie "odrzucaj" - taki sposb komentowania jest zupenie wyczony. Jeli wybrane jest ustawienie "adne" - komentarze dokonywane w opisany sposb bd traktowane jak zwyke komentarze.');
@define('PLUGIN_EVENT_SPAMBLOCK_API_MODERATE', 'moderuj');
@define('PLUGIN_EVENT_SPAMBLOCK_API_REJECT', 'odrzucaj');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_API', 'Niedozwolone jest komentowanie via API (jak np. lady (Trackbacki))');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE', 'Aktywuj filtr sowny');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE_DESC', 'Przeszukuje komentarze na okoliczno wystpienia pewnych cigw znakw i oznacza je jako spam');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS', 'Filtr URLi');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC', 'Dozwolone s wyraenia regularne, oddzielaj wyraenia rednikami (;)');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS', 'Filtr nazw autorw');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC', 'Dozwolone s wyraenia regularne, oddzielaj wyraenia rednikami (;)');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS', 'Filtr treci komentarza');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CHECKMAIL', 'Zy adres e-mail');
@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL', 'Sprawdza adresy e-mail?');
@define('PLUGIN_EVENT_SPAMBLOCK_REQUIRED_FIELDS', 'Wymagane pola komentarza');
@define('PLUGIN_EVENT_SPAMBLOCK_REQUIRED_FIELDS_DESC', 'Wprowad list wymaganych pl, ktre musz by wypenione przez uytkownika. Rozdzielaj pola przecinkami (,). Dostpne nazwy pl: name, email, url, replyTo, comment');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_REQUIRED_FIELD', 'Nie wypenie pola  %s!');

@define('PLUGIN_EVENT_SPAMBLOCK_CONFIG', 'Konfiguracja metod atyspamowych');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR', 'Blokuj tego autora przez wtyczk Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_URL', 'Blokuj ten URL przez wtyczk Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR', 'Odblokuj tego autora we wtyczce Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL', 'Odblokuj ten URL we wtyczce Obrona przed spamem');

@define('PLUGIN_EVENT_SPAMBLOCK_BLOGG_SPAMLIST', 'Filtruj URLe za pomoc Blacklisty serwisu blogg.de');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST', 'Zidentyfikowane jako spam na podstawie Blacklisty serwisu blogg.de');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_TITLE', 'Tytu wpisu jest taki sam jak tre komentarza');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_TITLE', 'Odrzucaj komentarze, ktre zawieraj tylko tytu');

@define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL', 'Sprawdzaj URLe ladw (Trackbackw)');
@define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL_DESC', 'Zezwl na pozostawienie ladu (Trackback) tylko gdy zawiera on link do Twojego bloga');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_TRACKBACKURL', 'Zy URL ladu (Trackbacka)');

@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_SCRAMBLE', 'Rozstrzelone captcha');

@define('PLUGIN_EVENT_SPAMBLOCK_HIDE', 'Wycz wtyczk dla Autorw');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_DESC', 'Moesz zezwoli na komentowanie wpisw przez Autorw nalecych do zaznaczonych grup bez wczonej ochorny antyspamowej.');

@define('PLUGIN_EVENT_SPAMBLOCK_AKISMET', 'Klucz Akismet API');
@define('PLUGIN_EVENT_SPAMBLOCK_AKISMET_DESC', 'Akismet.com to centralny serwer antyspamowy i zawierajcy tzw. blacklisty. Moe analizowa komentarze i sprawdza, czy taki komentarz zosta zgoszony jako spam. Akismet zosta stworzony dla systemu WordPress ale moe by wykorzystywany przez inne systemy. Potrzebujesz klucza API (API Key) ze strony http://www.akismet.com - klucz otrzymasz po rejestracji w serwisie http://www.wordpress.com/. Jeli pozostawisz to pole puste, technologia Akismet nie bdzie wykorzystywana.');
@define('PLUGIN_EVENT_SPAMBLOCK_AKISMET_FILTER', 'Jak traktowa spam zgoszony przez Akismet');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_AKISMET_SPAMLIST', 'Uyto filtra Akismet.com Blacklist');

?>

==> serendipity_1.1.4.orig.tar.gz: serendipity/plugins/serendipity_event_spamblock/lang_pl.inc.php <==
<?php # $Id: lang_pl.inc.php 1549 2006-12-20 18:26:51Z garvinhicking $

/**
 *  @version $Revision: 1549 $
 *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_EVENT_SPAMBLOCK_TITLE', 'Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_DESC', 'Rne metody na zwalczanie spamu w komentarzach');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY', 'Obrona przed spamem: Nieprawidowy komentarz.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_IP', 'Obrona przed spamem: Nie moesz wprowadzi kolejnego komentarza tak prdko. Prosz, poczekaj chwil (obrona przed floodem).');

@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_KILLSWITCH', 'Ten blog znajduje si w trybie "Cakowita blokada komentarzy". Prosz, wr tu za jaki czas, kiedy ten tryb zostanie zniesiony.');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE', 'Nie zezwalaj na zduplikowane komentarze');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE_DESC', 'Nie zezwalaj uytkownikom na dodanie komentarza, ktry ma tak sam zawarto jak dopiero co dodany komentarz (kolejne dodanie takiego samego komentarza)');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH', 'Cakowita blokada komentarzy');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH_DESC', 'Czasowe wyczenie moliwoci komentowania dla wszystkich wpisw. Przydatne kiedy Twj blog jest pod zmasowanym spamerskim atakiem.');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD', 'Czas blokowania adresu IP');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD_DESC', 'Zezwl na komentarze z danego adresu IP co n minut. Przydatne dla blokowania komentarzowych floodw (wiele komentarzy z tego samego adresu IP w krtkim czasie).');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS', 'Wcz Captcha');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_DESC', 'Wymusza na uytkowniku wpisanie specjalnego losowego kodu wywietlanego w wygenrowanym obrazku. Prosz, zwr uwag na to, e ludzie majcy problemy ze wzrokiem mog mie problemy z odczytaniem kodu.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC', 'Prosz, wpisz widoczny na obrazku kod do odpowiedniego pola. Twj komentarz zostanie dodany tylko gdy wpisany kod bdzie si zgadza z tym widocznym na obrazku. Prosz, upewnij si, e Twoja przegldarka ma wczon obsug cookies (ciasteczek) lub Twj komentarz nie przejdzie poprawnie weryfikacji.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2', 'Wpisz cig znakw, ktry tu widzisz do odpowiedniego pola!');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC3', 'Wpisz cig znakw widoczny na obrazku powyej: ');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_CAPTCHAS', 'Wprowadzie(a) nieprawidowy cig. Zerknij na obrazek i wprowad odpowiedni cig ponownie.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_NOTTF', 'Captcha nie bdzie dziaao na Twoim serwerze. Potrzebujesz zainstalowanych bibliotek GDLib i freetype oraz upewnij si, e odpowiednie pliki .ttf znajuj si w katalogu wtyczki.');

@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL', 'Wymu Captcha po ilu dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL_DESC', 'Moesz wymusi uzycie Captcha po okrelonej iloci dni. Wprowad iloc dni, po ktrych wprowadzenie Captcha bdzie wymagane. Jeli ustawione na 0 - bdzie wymagane zawsze.');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION', 'Wymu moderowanie komentarzy po ilu dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION_DESC', 'Moesz ustawi wymg moderowania wszystkich komentarzy. Wprowad ilo dni, po ktrych komentarze powinny podlega auto-moderacji. 0 wycza automoderacj.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE', 'Jak wiele linkw musi wystpi by komentarz podlega moderacji');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE_DESC', 'Jeli w komentarzu wystpi podana ilo linkw bdzie on wymaga moderacji. 0 oznacza wyczenie tej opcji.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT', 'Jak wiele linkw musi wystpi by komentarz zosta odrzucony');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT_DESC', 'Jeli w komentarzu wystpi podana ilo linkw, komentarz zostanie automatycznie odrzucony. 0 oznacza wyczenie tej opcji.');

@define('PLUGIN_EVENT_SPAMBLOCK_NOTICE_MODERATION', 'Z powodu warunkw okrelonych przez administratora bloga, Twj komentarz zosta oznaczony jako "wymagajcy sprawdzenia".');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR', 'Kolor ta captcha');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR_DESC', 'Wprowad wartoci RGB: 0,255,255');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE', 'Pooenie pliku z logiem');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE_DESC', 'Informacja o odrzuconych/wymagajcych moderowania komentarzach moe by przechowywania w pliku. Wyczy to pole jeli chcesz wyczy logowanie.');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_KILLSWITCH', 'Nagy wypadek: moliwo komentowania zostaa wyczona');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BODYCLONE', 'Zduplikowany komentarz');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_IPFLOOD', 'Zablokowane IP');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CAPTCHAS', 'Bdnie wprowadzone captcha (wprowadzono: %s, powinno by: %s)');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION', 'Auto-moderacja po X dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_REJECT', 'Zbyt wiele linkw');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_MODERATE', 'Zbyt wiele linkw');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL', 'Ukryj adresy e-mail komentujcych');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_DESC', 'Adresy e-mail komentujcych nie bd pokazywane');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_NOTICE', 'Adresy e-mail nie bd pokazywane i bd uywane tylko do celw wysyania powiadomie drog e-mailow');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE', 'Wybierz metod logowania');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DESC', 'Logi o odrzuconych komentarzach mog by przechowywane w Bazie danych lub w pliku tekstowym');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_FILE', 'Plik (patrz "Pooenie pliku z logiem")');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DB', 'Baza danych');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_NONE', 'Bez logowania');

@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS', 'Jak obsugiwa komentarze dokonywane via API');
@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS_DESC', 'To ustawienie odnosi si do komentarzy przesyanych przez API (lady (Trackbacks), WFW:commentAPI). Jeli wybrane jest ustawienie "moderuj", wszystkie te komentarze zawsze musz by wpierw zatwierdzone. Jeli wybrane jest ustawienie "odrzucaj" - taki sposb komentowania jest zupenie wyczony. Jeli wybrane jest ustawienie "adne" - komentarze dokonywane w opisany sposb bd traktowane jak zwyke komentarze.');
@define('PLUGIN_EVENT_SPAMBLOCK_API_MODERATE', 'moderuj');
@define('PLUGIN_EVENT_SPAMBLOCK_API_REJECT', 'odrzucaj');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_API', 'Niedozwolone jest komentowanie via API (jak np. lady (Trackbacki))');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE', 'Aktywuj filtr sowny');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE_DESC', 'Przeszukuje komentarze na okoliczno wystpienia pewnych cigw znakw i oznacza je jako spam');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS', 'Filtr URLi');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC', 'Dozwolone s wyraenia regularne, oddzielaj wyraenia rednikami (;)');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS', 'Filtr nazw autorw');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC', 'Dozwolone s wyraenia regularne, oddzielaj wyraenia rednikami (;)');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS', 'Filtr treci komentarza');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CHECKMAIL', 'Zy adres e-mail');
@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL', 'Sprawdza adresy e-mail?');
@define('PLUGIN_EVENT_SPAMBLOCK_REQUIRED_FIELDS', 'Wymagane pola komentarza');
@define('PLUGIN_EVENT_SPAMBLOCK_REQUIRED_FIELDS_DESC', 'Wprowad list wymaganych pl, ktre musz by wypenione przez uytkownika. Rozdzielaj pola przecinkami (,). Dostpne nazwy pl: name, email, url, replyTo, comment');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_REQUIRED_FIELD', 'Nie wypenie pola  %s!');

@define('PLUGIN_EVENT_SPAMBLOCK_CONFIG', 'Konfiguracja metod atyspamowych');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR', 'Blokuj tego autora przez wtyczk Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_URL', 'Blokuj ten URL przez wtyczk Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR', 'Odblokuj tego autora we wtyczce Obrona przed spamem');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL', 'Odblokuj ten URL we wtyczce Obrona przed spamem');

@define('PLUGIN_EVENT_SPAMBLOCK_BLOGG_SPAMLIST', 'Filtruj URLe za pomoc Blacklisty serwisu blogg.de');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST', 'Zidentyfikowane jako spam na podstawie Blacklisty serwisu blogg.de');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_TITLE', 'Tytu wpisu jest taki sam jak tre komentarza');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_TITLE', 'Odrzucaj komentarze, ktre zawieraj tylko tytu');

@define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL', 'Sprawdzaj URLe ladw (Trackbackw)');
@define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL_DESC', 'Zezwl na pozostawienie ladu (Trackback) tylko gdy zawiera on link do Twojego bloga');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_TRACKBACKURL', 'Zy URL ladu (Trackbacka)');

@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_SCRAMBLE', 'Rozstrzelone captcha');

@define('PLUGIN_EVENT_SPAMBLOCK_HIDE', 'Wycz wtyczk dla Autorw');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_DESC', 'Moesz zezwoli na komentowanie wpisw przez Autorw nalecych do zaznaczonych grup bez wczonej ochorny antyspamowej.');

@define('PLUGIN_EVENT_SPAMBLOCK_AKISMET', 'Klucz Akismet API');
@define('PLUGIN_EVENT_SPAMBLOCK_AKISMET_DESC', 'Akismet.com to centralny serwer antyspamowy i zawierajcy tzw. blacklisty. Moe analizowa komentarze i sprawdza, czy taki komentarz zosta zgoszony jako spam. Akismet zosta stworzony dla systemu WordPress ale moe by wykorzystywany przez inne systemy. Potrzebujesz klucza API (API Key) ze strony http://www.akismet.com - klucz otrzymasz po rejestracji w serwisie http://www.wordpress.com/. Jeli pozostawisz to pole puste, technologia Akismet nie bdzie wykorzystywana.');
@define('PLUGIN_EVENT_SPAMBLOCK_AKISMET_FILTER', 'Jak traktowa spam zgoszony przez Akismet');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_AKISMET_SPAMLIST', 'Uyto filtra Akismet.com Blacklist');

@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION_TREAT', 'Co zrobi z komentarzami, ktre bd automoderowane?');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATIONT_TREAT', 'Co zrobi ze ladami, ktre bd automoderowane?');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATIONT', 'Wymusza moderowanie ladw po jak wielu dniach');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATIONT_DESC', 'Moesz wymusi moderowanie wszelkich ladw do Twoich wpisw. Wprowad wiek wpisu (w dniach), po ktrym kady lad pozostawiany po tym terminie bdzie musia by moderowany przed opublikowaniem.');

@define('PLUGIN_EVENT_SPAMBLOCK_CSRF', 'Uy ochrony CSRF dla komentarzy?');
@define('PLUGIN_EVENT_SPAMBLOCK_CSRF_DESC', 'Po wczeniu tej opcji kademu komentarzowi bdzie przyporzdkowywana warto hash, dziki ktrej bdzie mona sprawdzi, czy komentarz zosta pozostawiony przez uytkownika z prawidowym ID sesji. To ustawienie zmniejszy ilos spamu i ograniczy moliwo komentowania przez CSRF ale jednoczenie uniemoliwi komentowanie uytkownikom nie korzystajcym z ciastek (cookies) w ich przegldarkach.');
@define('PLUGIN_EVENT_SPAMBLOCK_CSRF_REASON', 'Twj komentarz nie posiada numeru hash sesji. Komentarze mog by pozostawiane na tym blogu tylko gdy Twoja przegldarka ma wczon obsug ciasteczek (cookies)!');
